==> media_tableau-2.1.0.tar.gz: media_tableau/src/Plugin/Field/FieldFormatter/MediaTableauEmbedFormatter.php <==
<?php

declare(strict_types=1);

namespace Drupal\media_tableau\Plugin\Field\FieldFormatter;

use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\media_remote\Plugin\Field\FieldFormatter\MediaRemoteFormatterBase;

/**
 * Plugin implementation of the 'media_tableau' formatter.
 *
 * @FieldFormatter(
 *   id = "media_tableau",
 *   label = @Translation("Remote Media - Tableau"),
 *   field_types = {
 *     "string"
 *   }
 * )
 */
class MediaTableauEmbedFormatter extends MediaRemoteFormatterBase {

  /**
   * {@inheritdoc}
   */
  public static function getUrlRegexPattern() {
    $allowedHosts = \Drupal::configFactory()->get('media_tableau.settings')->get('allowed_hosts') ?? [];

    $hosts = [];
    foreach ($allowedHosts as $host) {
      $hosts[] = preg_quote($host, '/');
    }

    return '/^(' . implode('|', $hosts) . ')\/(app\/profile\/.*\/viz\/.*|views\/.*)/';
  }

  /**
   * {@inheritdoc}
   */
  public static function getValidUrlExampleStrings(): array {
    $allowedHosts = \Drupal::configFactory()->get('media_tableau.settings')->get('allowed_hosts') ?? [];

    $examples = [];
    foreach ($allowedHosts as $host) {
      $examples[] = $host . '/views/[your-tableau-viz-id]';
      $examples[] = $host . '/app/profile/[your-profile-name]/viz/[visualization-name]';
    }

    return $examples;
  }

  /**
   * {@inheritdoc}
   */
  public static function deriveMediaDefaultNameFromUrl($url) {
    $matches = [];
    $pattern = static::getUrlRegexPattern();
    preg_match_all($pattern, $url, $matches);
    if (!empty($matches[0][0])) {
      return t('Tableau view from @url', [
        '@url' => $url,
      ]);
    }
    return parent::deriveMediaDefaultNameFromUrl($url);
  }

  /**
   * {@inheritdoc}
   */
  public function viewElements(FieldItemListInterface $items, $langcode) {
    $elements = [];
    foreach ($items as $delta => $item) {
      /** @var \Drupal\Core\Field\FieldItemInterface $item */
      if ($item->isEmpty()) {
        continue;
      }
      $matches = [];
      $pattern = static::getUrlRegexPattern();
      preg_match_all($pattern, $item->value, $matches);

      if (empty($matches[0][0])) {
        continue;
      }

      $elements[$delta] = [
        '#theme' => 'media_tableau',
        '#url' => static::formatUrl($item->value),
        '#title' => $item->getParent()->getParent()->get('name')->value,
        '#width' => $this->getSetting('width'),
        '#height' => $this->getSetting('height'),
        '#attached' => [
          'library' => [
            'media_tableau/media_tableau_embedding.' . $this->getSetting('api_version'),
          ],
        ],
      ];
    }
    return $elements;
  }

  /**
   * Formats the visualization URL so it can be embedded.
   *
   * @return string
   *   The URL as a string.
   */
  public function formatUrl(string $url) {
    $profileRegexPattern = '/^(.*)\/app\/profile\/.*\/viz\/(?<viz_id>.*)/';

    $matches = NULL;
    preg_match($profileRegexPattern, $url, $matches);

    if (isset($matches['viz_id'])) {
      return $matches[1] . '/views/' . $matches['viz_id'];
    }
    else {
      return $url;
    }
  }

  /**
   * {@inheritdoc}
   */
  public static function defaultSettings() {
    return [
      'api_version' => 'latest',
      'width' => '100%',
      'height' => '900px',
    ] + parent::defaultSettings();
  }

  /**
   * {@inheritdoc}
   */
  public function settingsForm(array $form, FormStateInterface $form_state) {
    return parent::settingsForm($form, $form_state) + [
      'api_version' => [
        '#type' => 'select',
        '#title' => $this->t('API Version'),
        '#default_value' => $this->getSetting('api_version'),
        '#options' => [
          'latest' => $this->t('Latest'),
          '3.6' => $this->t('3.6'),
          '3.5' => $this->t('3.5'),
        ],
      ],
      'width' => [
        '#type' => 'textfield',
        '#title' => $this->t('Width'),
        '#default_value' => $this->getSetting('width'),
        '#size' => 5,
        '#maxlength' => 10,
        '#description' => $this->t('Valid css unit e.g. 500px, 100%, etc.'),
      ],
      'height' => [
        '#type' => 'textfield',
        '#title' => $this->t('Height'),
        '#default_value' => $this->getSetting('height'),
        '#size' => 5,
        '#maxlength' => 10,
        '#description' => $this->t('Valid css unit e.g. 500px, 100%, etc.'),
      ],
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function settingsSummary() {
    $summary = parent::settingsSummary();
    $summary[] = $this->t('Iframe size: %width , %height. <br> API version %version', [
      '%width' => $this->getSetting('width'),
      '%height' => $this->getSetting('height'),
      '%version' => $this->getSetting('api_version'),
    ]);
    return $summary;
  }

}

==> media_tableau-2.2.2.tar.gz: media_tableau/src/Plugin/Field/FieldFormatter/MediaTableauEmbedFormatter.php <==
<?php

declare(strict_types=1);

namespace Drupal\media_tableau\Plugin\Field\FieldFormatter;

use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\media_remote\Plugin\Field\FieldFormatter\MediaRemoteFormatterBase;

/**
 * Plugin implementation of the 'media_tableau' formatter.
 *
 * @FieldFormatter(
 *   id = "media_tableau",
 *   label = @Translation("Remote Media - Tableau"),
 *   field_types = {
 *     "string"
 *   }
 * )
 */
class MediaTableauEmbedFormatter extends MediaRemoteFormatterBase {

  /**
   * {@inheritdoc}
   */
  public static function getUrlRegexPattern() {
    $allowedHosts = \Drupal::configFactory()->get('media_tableau.settings')->get('allowed_hosts') ?? [];

    $hosts = [];
    foreach ($allowedHosts as $host) {
      $hosts[] = preg_quote($host, '/');
    }

    return '/^(' . implode('|', $hosts) . ')\/(.*\/)?(app\/profile\/.*\/viz\/.*|views\/.*)/';
  }

  /**
   * {@inheritdoc}
   */
  public static function getValidUrlExampleStrings(): array {
    $allowedHosts = \Drupal::configFactory()->get('media_tableau.settings')->get('allowed_hosts') ?? [];

    $examples = [];
    foreach ($allowedHosts as $host) {
      $examples[] = $host . '/views/[your-tableau-viz-id]';
      $examples[] = $host . '/app/profile/[your-profile-name]/viz/[visualization-name]';
    }

    return $examples;
  }

  /**
   * {@inheritdoc}
   */
  public static function deriveMediaDefaultNameFromUrl($url) {
    $matches = [];
    $pattern = static::getUrlRegexPattern();
    preg_match_all($pattern, $url, $matches);
    if (!empty($matches[0][0])) {
      return t('Tableau view from @url', [
        '@url' => $url,
      ]);
    }
    return parent::deriveMediaDefaultNameFromUrl($url);
  }

  /**
   * {@inheritdoc}
   */
  public function viewElements(FieldItemListInterface $items, $langcode) {
    $elements = [];
    foreach ($items as $delta => $item) {
      /** @var \Drupal\Core\Field\FieldItemInterface $item */
      if ($item->isEmpty()) {
        continue;
      }
      $matches = [];
      $pattern = static::getUrlRegexPattern();
      preg_match_all($pattern, $item->value, $matches);

      if (empty($matches[0][0])) {
        continue;
      }

      $elements[$delta] = [
        '#theme' => 'media_tableau',
        '#url' => static::formatUrl($item->value),
        '#title' => $item->getParent()->getParent()->get('name')->value,
        '#width' => $this->getSetting('width'),
        '#height' => $this->getSetting('height'),
        '#toolbar' => $this->getSetting('toolbar'),
        '#attached' => [
          'library' => [
            'media_tableau/media_tableau_embedding.' . $this->getSetting('api_version'),
          ],
        ],
      ];
    }
    return $elements;
  }

  /**
   * Formats the visualization URL so it can be embedded.
   *
   * @return string
   *   The URL as a string.
   */
  public function formatUrl(string $url) {
    $profileRegexPattern = '/^(.*)\/app\/profile\/.*\/viz\/(?<viz_id>.*)/';

    $matches = NULL;
    preg_match($profileRegexPattern, $url, $matches);

    if (isset($matches['viz_id'])) {
      return $matches[1] . '/views/' . $matches['viz_id'];
    }
    else {
      return $url;
    }
  }

  /**
   * {@inheritdoc}
   */
  public static function defaultSettings() {
    return [
      'api_version' => 'latest',
      'width' => '100%',
      'height' => '900px',
      'toolbar' => 0,
    ] + parent::defaultSettings();
  }

  /**
   * {@inheritdoc}
   */
  public function settingsForm(array $form, FormStateInterface $form_state) {
    return parent::settingsForm($form, $form_state) + [
      'api_version' => [
        '#type' => 'select',
        '#title' => $this->t('API Version'),
        '#default_value' => $this->getSetting('api_version'),
        '#options' => [
          'latest' => $this->t('Latest'),
          '3.6' => $this->t('3.6'),
          '3.5' => $this->t('3.5'),
        ],
      ],
      'width' => [
        '#type' => 'textfield',
        '#title' => $this->t('Width'),
        '#default_value' => $this->getSetting('width'),
        '#size' => 5,
        '#maxlength' => 10,
        '#description' => $this->t('Valid css unit e.g. 500px, 100%, etc.'),
      ],
      'height' => [
        '#type' => 'textfield',
        '#title' => $this->t('Height'),
        '#default_value' => $this->getSetting('height'),
        '#size' => 5,
        '#maxlength' => 10,
        '#description' => $this->t('Valid css unit e.g. 500px, 100%, etc.'),
      ],
      'toolbar' => [
        '#type' => 'checkbox',
        '#title' => $this->t('Display the toolbar'),
        '#default_value' => $this->getSetting('toolbar'),
        '#description' => $this->t('The toolbar is always shown if the view is hosted on Tableau Public.'),
      ],
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function settingsSummary() {
    $summary = parent::settingsSummary();
    $summary[] = $this->t('Iframe size: %width , %height. <br> Display toolbar: %toolbar <br> API version %version', [
      '%width' => $this->getSetting('width'),
      '%height' => $this->getSetting('height'),
      '%version' => $this->getSetting('api_version'),
      '%toolbar' => $this->getSetting('toolbar') ? 'Yes' : 'No',
    ]);
    return $summary;
  }

}
